@@ -18,6 +18,7 @@ from registry import *
 Registry = Registry()
 
 from constants import *
+from editabletext import *
 from role import *
 from state import *
 from text import *
@@ -112,6 +113,7 @@ Atspi.Accessible.description = property(fget=Atspi.Accessible.get_description)
 Atspi.Accessible.name = property(fget=Atspi.Accessible.get_name)
 Atspi.Accessible.isEqual = lambda a,b: a == b
 Atspi.Accessible.parent = property(fget=Atspi.Accessible.get_parent)
+Atspi.Accessible.setCacheMask = Atspi.Accessible.set_cache_mask
 
 Atspi.Accessible.toolkitName = property(fget=Atspi.Accessible.get_toolkit_name)
 Atspi.Accessible.toolkitVersion = property(fget=Atspi.Accessible.get_toolkit_version)
@@ -165,19 +167,15 @@ Atspi.Component.getMDIZOrder = Atspi.Component.get_mdi_z_order
 Atspi.Component.getPosition = lambda x,p: pointToList(Atspi.Component.get_position(x,p))
 Atspi.Component.getSize = lambda x: pointToList(Atspi.Component.get_size(x))
 Atspi.Component.grabFocus = Atspi.Component.grab_focus
+Atspi.Component.setExtents = Atspi.Component.set_extents
+Atspi.Component.setPosition = Atspi.Component.set_position
+Atspi.Component.setSize = Atspi.Component.set_size
 
 ### document ###
 Atspi.Accessible.queryDocument = lambda x: Document(getInterface(Atspi.Accessible.get_document, x))
 
 ### editable text ###
-EditableText = Atspi.EditableText
-Atspi.Accessible.queryEditableText = lambda x: getInterface(Atspi.Accessible.get_editable_text, x)
-Atspi.EditableText.copyText = Atspi.EditableText.copy_text
-Atspi.EditableText.cutText = Atspi.EditableText.cut_text
-Atspi.EditableText.deleteText = Atspi.EditableText.delete_text
-Atspi.EditableText.insertText = Atspi.EditableText.insert_text
-Atspi.EditableText.pasteText = Atspi.EditableText.paste_text
-Atspi.EditableText.setTextContents = Atspi.EditableText.set_text_contents
+Atspi.Accessible.queryEditableText = lambda x: EditableText(getInterface(Atspi.Accessible.get_text, x))
 
 ### hyperlink ###
 Hyperlink = Atspi.Hyperlink
@@ -207,8 +205,8 @@ Atspi.Image.imageLocale = property(fget=Atspi.Image.get_image_locale)
 
 ### selection ###
 Selection = Atspi.Selection
-Atspi.Accessible.querySelection = lambda x: getInterface(Atspi.Accessible.get_selection)
-Atspi.Selection.clearSelectio = Atspi.Selection.clear_selection
+Atspi.Accessible.querySelection = lambda x: getInterface(Atspi.Accessible.get_selection, x)
+Atspi.Selection.clearSelection = Atspi.Selection.clear_selection
 Atspi.Selection.deselectChild = Atspi.Selection.deselect_child
 Atspi.Selection.deselectSelectedChild = Atspi.Selection.deselect_selected_child
 Atspi.Selection.getSelectedChild = Atspi.Selection.get_selected_child
@@ -272,6 +270,8 @@ Atspi.Value.minimumValue = property(fget=Atspi.Value.get_minimum_value)
 ### event ###
 Atspi.Event.host_application = property(fget=lambda x: x.source.get_application())
 Atspi.Event.rawType = Atspi.Event.type
+Atspi.Event.source_name = property(fget=lambda x: x.source.name)
+Atspi.Event.source_role = property(fget=lambda x: x.source.getRole())
 Atspi.Event.type = property(fget=getEventType)
 
 ### RelationSet ###
@@ -325,3 +325,8 @@ BUTTON_RELEASED_EVENT = Atspi.EventType.BUTTON_RELEASED_EVENT
 KEY_PRESS = Atspi.KeySynthType.PRESS
 KEY_PRESSRELEASE = Atspi.KeySynthType.PRESSRELEASE
 KEY_RELEASE = Atspi.KeySynthType.RELEASE
+KEY_STRING = Atspi.KeySynthType.STRING
+KEY_SYM = Atspi.KeySynthType.SYM
+
+### cache ###
+cache = Atspi.Cache
